"use strict";
/**
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAddressCandidates = exports.JF_HTTPS_PORT = exports.JF_HTTP_PORT = void 0;
var url_1 = require("./url");
/** The default http port for Jellyfin servers. */
exports.JF_HTTP_PORT = 8096;
/** The default https port for Jellyfin servers. */
exports.JF_HTTPS_PORT = 8920;
/**
 * Gets the score of a url based on common server setups.
 * @param url The url to evaluate.
 * @returns The score.
 */
function getScore(url) {
    var score = 0;
    // Prefer secure connections
    if (url.protocol === url_1.HTTPS_PROTOCOL) {
        score += 5;
    }
    else {
        score -= 5;
    }
    if (url.port === exports.JF_HTTP_PORT.toString()) {
        score += 2; // Using the Jellyfin http port is common
    }
    else if (url.port === exports.JF_HTTPS_PORT.toString()) {
        score -= 1; // Using the Jellyfin https port is not common
    }
    // Prefer default ports for http(s) protocols
    if (url.protocol === url_1.HTTPS_PROTOCOL && (!url.port || url.port === url_1.HTTPS_PORT.toString())) {
        score += 3;
    }
    else if (url.protocol === url_1.HTTP_PROTOCOL && (!url.port || url.port === url_1.HTTP_PORT.toString())) {
        score += 3;
    }
    return score;
}
/**
 * Gets a list of address candidates url strings
 * from a provided url address string.
 * @param input A server url address string.
 * @returns A list of potential server addresses.
 */
function getAddressCandidates(input) {
    var candidates = [];
    try {
        var url = (0, url_1.parseUrl)(input);
        candidates.push(url);
        if (url.protocol === url_1.HTTP_PROTOCOL) {
            var copy = (0, url_1.copyUrl)(url);
            copy.protocol = url_1.HTTPS_PROTOCOL;
            candidates.push(copy);
        }
        candidates
            .filter(function (val) { return !val.port || val.port === (0, url_1.getDefaultPort)(val.protocol).toString(); })
            .forEach(function (val) {
            if (val.protocol === url_1.HTTP_PROTOCOL) {
                var copy = (0, url_1.copyUrl)(val);
                copy.port = exports.JF_HTTP_PORT.toString();
                candidates.push(copy);
            }
            else if (val.protocol === url_1.HTTPS_PROTOCOL) {
                var copy = (0, url_1.copyUrl)(val);
                copy.port = exports.JF_HTTP_PORT.toString();
                candidates.push(copy);
                copy = (0, url_1.copyUrl)(val);
                copy.port = exports.JF_HTTPS_PORT.toString();
                candidates.push(copy);
            }
        });
        return candidates
            .sort(function (a, b) { return getScore(b) - getScore(a); })
            .map(function (candidate) { return candidate.toString(); });
    }
    catch (err) {
        console.warn(err);
        return [];
    }
}
exports.getAddressCandidates = getAddressCandidates;
